==> haskell-validity-bytestring-0.4.1.1-1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-validity-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validity-bytestring
version:              0.4.1.1
visibility:           public
id:                   validity-bytestring-0.4.1.1-BhunEdgG00I5V3XlU1AHqN
key:                  validity-bytestring-0.4.1.1-BhunEdgG00I5V3XlU1AHqN
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Validity instances for bytestring
description:          Please see README.md
category:             Validity
abi:                  08c0c13c6609f026ee28bf1da9f6f73c
exposed:              True
exposed-modules:      Data.Validity.ByteString
hidden-modules:       Paths_validity_bytestring
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validity-bytestring
hs-libraries:         HSvalidity-bytestring-0.4.1.1-BhunEdgG00I5V3XlU1AHqN
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    validity-0.12.1.0-Lsdq3S1YVx6GOnXZaTodRl

haddock-interfaces:
    /usr/share/doc/haskell-validity-bytestring/html/validity-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-validity-bytestring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-validity-bytestring-0.4.1.1-2-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-validity-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validity-bytestring
version:              0.4.1.1
visibility:           public
id:                   validity-bytestring-0.4.1.1-IKmjHC9KlTpEiFvyHk4VuX
key:                  validity-bytestring-0.4.1.1-IKmjHC9KlTpEiFvyHk4VuX
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Validity instances for bytestring
description:          Please see README.md
category:             Validity
abi:                  6f25c7236c82e75bdd35a93f4de6ef2b
exposed:              True
exposed-modules:      Data.Validity.ByteString
hidden-modules:       Paths_validity_bytestring
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validity-bytestring
hs-libraries:         HSvalidity-bytestring-0.4.1.1-IKmjHC9KlTpEiFvyHk4VuX
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    validity-0.12.1.0-1ywEh9iJU1m6FQwCfRBtqj

haddock-interfaces:
    /usr/share/doc/haskell-validity-bytestring/html/validity-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-validity-bytestring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
